ChangeSet 1.1622, 2004/03/01 16:18:12-08:00, greg@kroah.com

PCI Hotplug: fix stupid directory name of "pci_hotplug_slots" to be just "slots"


 drivers/pci/hotplug/pci_hotplug_core.c |   15 +++++++++++++--
 1 files changed, 13 insertions(+), 2 deletions(-)


diff -Nru a/drivers/pci/hotplug/pci_hotplug_core.c b/drivers/pci/hotplug/pci_hotplug_core.c
--- a/drivers/pci/hotplug/pci_hotplug_core.c	Tue Mar  2 19:42:42 2004
+++ b/drivers/pci/hotplug/pci_hotplug_core.c	Tue Mar  2 19:42:42 2004
@@ -104,8 +104,19 @@
 	.release = &hotplug_slot_release,
 };
 
-decl_subsys(pci_hotplug_slots, &hotplug_slot_ktype, NULL);
-
+/* 
+ * We create a struct subsystem on our own and not use decl_subsys so
+ * we can have a sane name "slots" in sysfs, yet still keep a good
+ * global variable name "pci_hotplug_slots_subsys.
+ * If the decl_subsys() #define ever changes, this declaration will
+ * need to be update to make sure everything is initialized properly.
+ */
+struct subsystem pci_hotplug_slots_subsys = {
+	.kset = {
+		.kobj = { .name = "slots" },
+		.ktype = &hotplug_slot_ktype,
+	}
+};
 
 /* these strings match up with the values in pci_bus_speed */
 static char *pci_bus_speed_strings[] = {
